# Transaction SMS Parser

A library to parse transaction sms text to extract relevant information from it. A naive implementation using mostly regular expressions.

## How to use

The main method to use be used is:

```ts
getTransactionInfo(message: string): ITransactionInfo
```

It takes sms text as input and will give an object of `ITransactionInfo` type

```ts
interface ITransactionInfo {
  account: IAccountInfo;
  transactionAmount: string | null;
  transactionType: 'debit' | 'credit' | null;
  balance: IBalance | null;
}

interface IBalance {
  available: string | null;
  outstanding: string | null;
}

interface IAccountInfo {
  type: IAccountType | null;
  number: string | null;
  name: string | null;
}

enum IAccountType {
  CARD = 'CARD',
  WALLET = 'WALLET',
  ACCOUNT = 'ACCOUNT',
}
```

### Example

```ts
import { getTransactionInfo } from 'transaction-sms-parser';

const sms =
  'INR 2000 debited from A/c no. XX3423 on 05-02-19 07:27:11 IST at ECS PAY. Avl Bal- INR 2343.23.';

const transactionInfo = getTransactionInfo(sms);
```

```js
//output
{
    account: {
        type: 'ACCOUNT',
        number: '3423',
        name: null,
    },
    transactionAmount: '2000.00',
    transactionType: 'debit',
    balance: { available: '2343.23', outstanding: null },
}
```

API Documentation generated by typedoc is hosted on [gh-pages](https://saurabhgupta050890.github.io/transaction-sms-parser/)

## Testing

[How to unit test ?](./docs/UNIT_TESTS.md)

Tested with the SMS text from following banks/cards/wallets:

Banks:

- Axis
- ICICI
- Kotak
- HDFC
- Standard Charted
- IDFC
- Niyo global

Credit Cards:

- HSBC
- Citi Bank
- Sodexo
- ICICI
- Uni Card
- Indusind Bank
- Slice

Wallets

- Paytm
- Amazon pay
- Lazypay
- Simpl
